@@ -13,7 +13,8 @@ sub initialize_body {
     # of the possible use cases (even if it
     # requires some adaption on the part of
     # the author, after all, nothing is free)
-    my $source = 'sub {';
+    my $source = "use Carp qw( confess );\n";
+    $source .= 'sub {';
     $source .= "\n" . 'my $class = shift;';
 
     $source .= "\n" . 'my $existing = do { no strict "refs"; \${"$class\::singleton"}; };';
@@ -64,7 +65,7 @@ sub initialize_body {
         $code = eval $source;
         confess "Could not eval the constructor :\n\n$source\n\nbecause :\n\n$@" if $@;
     }
-    $self->{'&!body'} = $code;
+    $self->{'body'} = $code;
 }
 
 no Moose;
